### Built With :

- tkinter & CustomTkinter (Python built-in)
- imageio
- Pillow

### Installation:

The pip command to install ttkinter videos library for use

This will create a shim between your code and the module binaries that gets updated every time you change your code.

### Usage :

- Import tkinter and tkvideo-moviepy
- Create Tk() parent and the label you'd like to use
- Get a moviepy video
- Create tkvideo object with its parameters(video_path, label_name,number of loops for the video if required and size of the video_screen)
- Start the player thread with .play()
- Start the Tk mainloop

#### Official release :

For the updtaed version Latest version.

### License

Distributed under the MIT License. See LICENSE for more information.